(current-latest-map lib coord config)Returns a map containing :current and :latest if the dependency has a
newer version otherwise returns nil.
Returns a map containing `:current` and `:latest` if the dependency has a newer version otherwise returns `nil`.
(newer-versions loc config)Find all deps in a :deps or :extra-deps or :override-deps map to be updated,
at the top level and in aliases.
loc points at the top level map.
Find all deps in a `:deps` or `:extra-deps` or `:override-deps` map to be updated, at the top level and in aliases. `loc` points at the top level map.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |