(try-update-artifact loc consider-types repos)Attempt to update a specific version in a :deps or :extra-deps map.
loc points at the artifact name (map key).
Attempt to update a specific version in a `:deps` or `:extra-deps` map. `loc` points at the artifact name (map key).
(update-aliases loc consider-types repos)Update all :aliases, expects a loc pointing at the :aliases map.
Update all `:aliases`, expects a loc pointing at the `:aliases` map.
(update-all loc consider-types repos)Update all :deps, :extra-deps, and :aliases.
Expects a loc to the top level deps.edn map.
consider-types is a set, one of depot.outdated/version-types.
repos is a map with optional keys :mvn/repos and :mvn/local-repo.
Update all `:deps`, `:extra-deps`, and `:aliases`. Expects a loc to the top level `deps.edn` map. `consider-types` is a set, one of [[depot.outdated/version-types]]. `repos` is a map with optional keys `:mvn/repos` and `:mvn/local-repo`.
(update-deps loc consider-types repos)Update all deps in a :deps or :extra-deps map.
loc points at the map.
Update all deps in a `:deps` or `:extra-deps` map. `loc` points at the map.
(update-deps-edn! file consider-types)Destructively update a deps.edn file.
Read a deps.edn file, update all dependencies in it to their latest version,
unless marked with ^:depot/ignore metadata, then overwrite the file with the
updated version. Preserves whitespace and comments.
This will consider user and system-wide deps.edn files for locating Maven
repositories, but only considers the given file when determining current
versions.
consider-types is a set, one of depot.outdated/version-types.
Destructively update a `deps.edn` file. Read a `deps.edn` file, update all dependencies in it to their latest version, unless marked with `^:depot/ignore` metadata, then overwrite the file with the updated version. Preserves whitespace and comments. This will consider user and system-wide `deps.edn` files for locating Maven repositories, but only considers the given file when determining current versions. `consider-types` is a set, one of [[depot.outdated/version-types]].
(update-loc? loc)Should the version at the current position be updated?
Returns true unless any ancestor has the ^:depot/ignore metadata.
Should the version at the current position be updated? Returns true unless any ancestor has the `^:depot/ignore` metadata.
(zget loc key)Like [[clojure.core/get]], but for a zipper over a map.
Takes and returns a zipper (loc).
Like [[clojure.core/get]], but for a zipper over a map. Takes and returns a zipper (loc).
(zip-skip-ws loc)Skip whitespace, comments, and uneval nodes.
Skip whitespace, comments, and uneval nodes.
(zmap-vals loc f & args)Given a zipper pointing at a map, apply a tranformation to each value of the map.
Given a zipper pointing at a map, apply a tranformation to each value of the map.
(zright loc)Like [[rewrite-clj.zip/right]], but also skip over uneval nodes
Like [[rewrite-clj.zip/right]], but also skip over uneval nodes
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |